@@ -22,9 +22,10 @@
 #include <map>
 #include <cassert>
 
+#include "test_macros.h"
 #include "is_transparent.h"
 
-#if _LIBCPP_STD_VER <= 11
+#if TEST_STD_VER <= 11
 #error "This test requires is C++14 (or later)"
 #else
 
@@ -36,4 +37,4 @@ int main()
     M().equal_range(C2Int{5});
     }
 }
-#endif
\ No newline at end of file
+#endif
